<?php
/**
 * @file
 * Contains \Drupal\goat_api\Form\ChiForm.
 */
namespace Drupal\goat_api\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerTrait;
use Drupal\Core\Render\Markup;


class ChiForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'chi_form';
  }
  /**
   * @inheritdoc
   */
  protected function getEditableConfigNames() {
    return ['goat_api.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['#cache'] = [
      'max-age' => 0,   // prevent caching
    ];

    $config = $this->config('goat_api.settings');
    $form['num_images'] = array(
      '#type' => 'number',
      '#title' => t('Number of images to fetch:'),
      '#required' => false,
      '#min' => 1,
      '#max' => 99,
      '#size' => 2,
      '#default_value' => $config->get('chi_num_images') ?? 5,
    );

    $form['output'] = array(
      '#type' => 'value',
      '#text' => $config->get('form_table_data') ?? '',
    );

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = array(
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $config = $this->config('goat_api.settings');
    $num_images = $form_state->getValue('num_images');
    $config->set('chi_num_images', $num_images);

    // fetch the data from the art institute
    $client = \Drupal::httpClient();

    try {
      $response = $client->get('https://api.artic.edu/api/v1/artworks/search?q=goats&fields=id,title,image_id&limit=' . $num_images);
    } catch (RequestException $e) {
      drupal_set_message('Could not fetch data from AIC', 'error', TRUE);
      return FALSE;
    }

    // build table of output
    $header = [
      'col1' => t('Title'),
      'col2' => t('Image'),
    ];
    $rows = [];

    $raw = json_decode($response->getBody(), TRUE);
    foreach ($raw['data'] as $item) {
      $title = $item['title'];
      $image_id = $item['image_id'];
      $img_url = 'https://www.artic.edu/iiif/2/' . $image_id . '/full/200,/0/default.jpg';
      $image_full = Markup::create('<img src="' . $img_url . '" alt="' . $title . '">');
      $rows[] = [$title, $image_full];
    }


    $table = array(
      '#theme' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#empty' => t('No books available.'),
    );

    $render_service = \Drupal::service('renderer');
    $table_output = $render_service->renderPlain($table);
    $config->set('form_table_data', $table_output);
    $config->save();

    return;
  }

}
